View source: R/Spatial utilities.R
| calculate_proximity_weight | R Documentation |
This function calculates the distance between a shallower and deeper depth to a target depth. These values are then swapped so they can be used in a weighted average to linearly interpolate to the target depth.
calculate_proximity_weight(depths, target)
depths |
A numeric vector of a shallower and deeper depth. |
target |
An intermediate depth we would like to interpolate to. |
A vector of weights to match the vector of depths.
Other NEMO-MEDUSA spatial tools:
calculate_depth_share(),
netcdf_scheme_helpers,
scheme_column(),
scheme_interp_slice(),
scheme_strathE2E(),
stratify(),
voronoi_grid(),
xyindex_to_nindex()
calculate_proximity_weight(c(0, 100), target = 30) calculate_proximity_weight(c(0, 100), target = 50) calculate_proximity_weight(c(0, 100), target = 80)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.