View source: R/Spatial utilities.R
| xyindex_to_nindex | R Documentation |
This function converts a double index for a matrix (xy) into a single index for values. This allows vectorised subsetting of incomplete rows and columns.
xyindex_to_nindex(x, y, nrow)
x |
vector of row numbers for target values. |
y |
vector of column numbers for target values. |
nrow |
The number of rows in the matrix |
A vector of indices for values in a matrix.
Other NEMO-MEDUSA spatial tools:
calculate_depth_share(),
calculate_proximity_weight(),
netcdf_scheme_helpers,
scheme_column(),
scheme_interp_slice(),
scheme_strathE2E(),
stratify(),
voronoi_grid()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.